# Changelog

<!--next-version-placeholder-->

## v0.1.0 (2025-05-02)

### Feature

* Initial implementation of uuid7. Fails sub-ms sorting right now. ([`63d4824`](https://github.com/educationwarehouse/uuid7/commit/63d482401e387ee8bb67761180d1abb63e1e2aca))

### Fix

* Improved implementation with even better sorting precision (μs resolution, 1ns would cost too much entropy) ([`8fed9ef`](https://github.com/educationwarehouse/uuid7/commit/8fed9ef6fb04430f2cc96d342cf8328f96445890))
* Improved sequential part but it can still fail ([`4898b42`](https://github.com/educationwarehouse/uuid7/commit/4898b42b1f481ac8ce94283d1d45668063d3fe88))

### Documentation

* Added output in comments for examples ([`ac520b8`](https://github.com/educationwarehouse/uuid7/commit/ac520b873a03f7177026b6a467b12441ea37fca7))
* Switched back to proper markdown table ([`8671437`](https://github.com/educationwarehouse/uuid7/commit/867143753390f03964cc2aad8c98e280061069c8))
* Updated readme with examples, new table ([`542a699`](https://github.com/educationwarehouse/uuid7/commit/542a69939424227806b62dc1cfca70bd3c332727))
